@@ -16,7 +16,7 @@ WebDAO::Lib::MethodByPath - Component for method tag
 use WebDAO::Base;
 use Data::Dumper;
 use base qw(WebDAO::Component);
-__PACKAGE__->attributes qw( _path _args );
+__PACKAGE__->mk_attr( _path=>undef, _args=>undef);
 
 sub init {
     my $self = shift;
@@ -47,7 +47,7 @@ Zahatski Aliaksandr, E<lt>zag@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2002-2009 by Zahatski Aliaksandr
+Copyright 2002-2012 by Zahatski Aliaksandr
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
